@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # isbnlib - tools for extracting, cleaning and transforming ISBNs
-# Copyright (C) 2014-2022 Alexandre Lima Conde
+# Copyright (C) 2014-2023 Alexandre Lima Conde
 # SPDX-License-Identifier: LGPL-3.0-or-later
 
 # This program is free software: you can redistribute it and/or modify
@@ -46,11 +46,10 @@ RE_NORMAL = re.compile(
     re.I | re.M | re.S,
 )
 RE_LOOSE = re.compile(r'[- 0-9X]{10,19}', re.I | re.M | re.S)
-ISBN13_PREFIX = '978'
+ISBN13_PREFIX = '978'  # just the prefix with isbn-10
 LEGAL = '0123456789xXisbnISBN- '
 
 
-# pylint: disable=broad-except
 def check_digit10(firstninedigits):
     """Check sum ISBN-10."""
     # minimum checks
@@ -58,7 +57,7 @@ def check_digit10(firstninedigits):
         return ''
     try:
         int(firstninedigits)
-    except Exception:  # pragma: no cover
+    except ValueError:  # pragma: no cover
         return ''
     # checksum
     val = sum(
@@ -73,7 +72,6 @@ def check_digit10(firstninedigits):
     return str(tenthdigit)
 
 
-# pylint: disable=broad-except
 def check_digit13(firsttwelvedigits):
     """Check sum ISBN-13."""
     # minimum checks
@@ -81,7 +79,7 @@ def check_digit13(firsttwelvedigits):
         return ''
     try:
         int(firsttwelvedigits)
-    except Exception:  # pragma: no cover
+    except ValueError:  # pragma: no cover
         return ''
     # checksum
     val = sum(
