@@ -9,8 +9,10 @@ from .dev.webquery import query as wquery
 LOGGER = logging.getLogger(__name__)
 
 UA = 'isbnlib (gzip)'
-SERVICE_URL = ('https://www.googleapis.com/books/v1/volumes?q=isbn:{isbn}'
-               '&fields=items/volumeInfo(imageLinks)&maxResults=1')
+SERVICE_URL = (
+    'https://www.googleapis.com/books/v1/volumes?q=isbn:{isbn}'
+    '&fields=items/volumeInfo(title,subtitle,authors,publisher,publishedDate,'
+    'language,industryIdentifiers,description,imageLinks)&maxResults=1')
 
 
 @cache
