@@ -11,9 +11,10 @@ from .dev.webservice import query as wsquery
 LOGGER = logging.getLogger(__name__)
 
 UA = 'isbnlib (gzip)'
-SERVICE_URL = ('https://www.googleapis.com/books/v1/volumes?q=isbn:{isbn}'
-               '&fields=items/volumeInfo(description)'
-               '&maxResults=1')
+SERVICE_URL = (
+    'https://www.googleapis.com/books/v1/volumes?q=isbn:{isbn}'
+    '&fields=items/volumeInfo(title,subtitle,authors,publisher,publishedDate,'
+    'language,industryIdentifiers,description,imageLinks)&maxResults=1')
 
 
 # pylint: disable=broad-except
