@@ -46,7 +46,11 @@ def isbn_from_words(words):
 
 def doi(isbn):
     """Return a DOI's ISBN-A from a ISBN-13."""
-    return '10.%s.%s%s/%s%s' % tuple(msk(EAN13(isbn), '-').split('-'))
+    try:
+        value = '10.%s.%s%s/%s%s' % tuple(msk(EAN13(isbn), '-').split('-'))
+    except TypeError:
+        return ''
+    return value
 
 
 def ren(fp):
