@@ -31,11 +31,14 @@ def goos(words):
         },
     )
     isbns = get_isbnlike(content)
-
-    for item in isbns:
-        isbn = get_canonical_isbn(item, output='isbn13')
-        if isbn:  # pragma: no cover
-            break
+    isbn = ''
+    try:
+        for item in isbns:
+            isbn = get_canonical_isbn(item, output='isbn13')
+            if isbn:  # pragma: no cover
+                break
+    except IndexError:  # pragma: no cover
+        pass
     if not isbns or not isbn:  # pragma: no cover
         LOGGER.debug('No ISBN found for %s', words)
-    return isbn if isbn else None
+    return isbn
