@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
 """Read and write to a dict-like cache."""
 
-from collections import MutableMapping
+try:
+    from collections.abc import MutableMapping  # noqa
+except ImportError:  # PY27
+    from collections import MutableMapping  # noqa
 
 
 class IMCache(MutableMapping):
@@ -9,6 +12,7 @@ class IMCache(MutableMapping):
 
     MAXLEN = 1000
 
+    # pylint: disable=keyword-arg-before-vararg
     def __init__(self, maxlen=MAXLEN, *a, **k):
         self.filepath = 'IN MEMORY'
         self.maxlen = maxlen
@@ -30,6 +34,9 @@ class IMCache(MutableMapping):
             self.popitem()
         self.d[k] = v
 
+    def __contains__(self, key):
+        return key in self.d
+
     def __delitem__(self, k):
         del self.d[k]
 
@@ -40,6 +47,7 @@ class IMCache(MutableMapping):
     __nonzero__ = __bool__
 
     def __call__(self, k):
+        """Implement function call operator."""
         try:
             return self.__getitem__(k)
         except KeyError:
