@@ -6,7 +6,7 @@ import re
 
 from .dev import stdmeta
 from .dev._bouth23 import u
-from .dev._exceptions import RecordMappingError
+from .dev._exceptions import DataNotFoundAtServiceError, RecordMappingError
 from .dev.webquery import query as wquery
 
 UA = 'isbnlib (gzip)'
@@ -74,5 +74,9 @@ def _records(isbn, data):
 
 def query(isbn):
     """Query the openlibrary.org service for metadata."""
-    data = wquery(SERVICE_URL.format(isbn=isbn), user_agent=UA)
+    try:
+        data = wquery(SERVICE_URL.format(isbn=isbn), user_agent=UA)
+    except DataNotFoundAtServiceError:
+        LOGGER.debug('No data from "openl" for isbn %s', isbn)
+        return {}
     return _records(isbn, data)
