@@ -2,14 +2,15 @@
 # flake8: noqa
 # pylint: skip-file
 """
-nose tests
+tests
 """
+import pytest
 
 from ..dev.webservice import query as wsquery
-from nose.tools import assert_equals
 
+pytestmark = pytest.mark.network
 
 def test_webservice():
     """Test that values can be passed to a WebService query."""
-    assert_equals(len(repr(wsquery("http://example.org", values={'some': 'values'}))) > 0,
-                  True)
+    assert (
+        (len(repr(wsquery('http://example.org', values={'some': 'values'}))) > 0) == True)
